@@ -389,7 +389,7 @@ class Config:
 
         group = OptionGroup(self.parser, 'APPLICATION VERSION',
                             'The name and version number of the web appli'
-                            'cation to install e.g. phpmyadmin 2.5.4. The'
+                            'cation to install e.g. phpmyadmin 2.5.4. The '
                             'APPLICATION must have already been installed'
                             ' into the '
                             + self.config.get('USER', 'my_approot') +
@@ -593,6 +593,14 @@ class Config:
                          'or version number as arguments to restrict the '
                          'listing.')
 
+        group.add_option('--prune-database',
+                         '--pd',
+                         type = 'choice',
+                         choices = ['pretend',
+                                    'clean'],
+                         help = 'This will list all outdated entries in '
+                         'the webapp-config "database".')
+
         group.add_option('--show-installed',
                          '--si',
                          action='store_true',
@@ -932,7 +940,7 @@ class Config:
         # set the action to be performed
         work = ['install', 'clean', 'upgrade', 'list_installs',
                 'list_servers', 'list_unused_installs',
-                'show_installed', 'show_postinst',
+                'prune_database', 'show_installed', 'show_postinst',
                 'show_postupgrade', 'check_config', 'query']
 
         for i in work:
@@ -940,6 +948,9 @@ class Config:
                 self.work = i
                 break
 
+        if options.__dict__.get('prune_database'):
+            self.prune_action = options.__dict__.get('prune_database')
+
         OUT.debug('Checking command line arguments', 1)
 
         if len(args) > 0:
@@ -983,7 +994,8 @@ class Config:
 
         j = len(subdomains)
         for i in subdomains:
-            self.config.set('USER', 'vhost_subdomain_' + str(j), i)
+            if not self.maybe_get('USER', 'vhost_subdomain_' + str(j)):
+                self.config.set('USER', 'vhost_subdomain_' + str(j), i)
 
             OUT.debug('Storing subdomain name', 8)
 
@@ -1134,6 +1146,15 @@ class Config:
             self.create_webapp_db(  self.maybe_get('cat'),
                                     self.maybe_get('pn'),
                                     self.maybe_get('pvr')).listinstalls()
+        if self.work == 'prune_database':
+            # Get the handler for the virtual install db. If the action is equal
+            # to clean, then it'll simply prune the "db" of outdated entries.
+            # If it's not set to clean, then it'll list the outdated entries
+            # in the db to be cleaned out.
+            self.__r = wrapper.get_root(self)
+            self.create_webapp_db(  self.maybe_get('cat'),
+                                    self.maybe_get('pn'),
+                                    self.maybe_get('pvr')).prune_database(self.prune_action)
 
         if self.work == 'show_installed':
 
